Documentation
¶
Overview ¶
Package apps provides application detection and configuration functionality.
Index ¶
- type AppDetector
- func (d *AppDetector) AutoDetectApps() ([]*config.AppConfig, error)
- func (d *AppDetector) DetectApp(appName string) (*config.AppConfig, error)
- func (d *AppDetector) GetInstalledApps() []InstalledApp
- func (d *AppDetector) GetSupportedApps() []string
- func (d *AppDetector) ScanInstalledApps() ([]InstalledApp, error)
- type AppInfo
- type InstalledApp
- type PathInfo
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AppDetector ¶
type AppDetector struct {
// contains filtered or unexported fields
}
AppDetector handles detection and configuration of macOS applications
func NewAppDetector ¶
func NewAppDetector(homeDir string) *AppDetector
NewAppDetector creates a new application detector
func (*AppDetector) AutoDetectApps ¶
func (d *AppDetector) AutoDetectApps() ([]*config.AppConfig, error)
AutoDetectApps automatically detects applications and generates configurations
func (*AppDetector) DetectApp ¶
func (d *AppDetector) DetectApp(appName string) (*config.AppConfig, error)
DetectApp attempts to detect an application and its configuration paths
func (*AppDetector) GetInstalledApps ¶
func (d *AppDetector) GetInstalledApps() []InstalledApp
GetInstalledApps returns the cached list of installed apps
func (*AppDetector) GetSupportedApps ¶
func (d *AppDetector) GetSupportedApps() []string
GetSupportedApps returns a list of known supported applications
func (*AppDetector) ScanInstalledApps ¶
func (d *AppDetector) ScanInstalledApps() ([]InstalledApp, error)
ScanInstalledApps scans the system for installed applications using system_profiler and mdfind
Click to show internal directories.
Click to hide internal directories.